"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _startCase2 = _interopRequireDefault(require("lodash/startCase"));

var _react = _interopRequireWildcard(require("react"));

var _core = require("@runly/core");

var _loading = _interopRequireDefault(require("./loading"));

var _retry = _interopRequireDefault(require("./retry"));

function _getRequireWildcardCache() { if (typeof WeakMap !== "function") return null; var cache = new WeakMap(); _getRequireWildcardCache = function () { return cache; }; return cache; }

function _interopRequireWildcard(obj) { if (obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const RunProgress = ({
  org,
  runId,
  allowRetry = true
}) => {
  const [retryRunId, setRetryRunId] = (0, _react.useState)();
  const onRequeued = (0, _react.useCallback)(r => setRetryRunId(r.id), []);
  const {
    run
  } = (0, _core.useRunConnection)(org, retryRunId || runId);

  if (!run) {
    return /*#__PURE__*/_react.default.createElement(_loading.default, null);
  }

  if (isProgressEmpty(run.progress)) {
    return /*#__PURE__*/_react.default.createElement("h4", null, /*#__PURE__*/_react.default.createElement("span", {
      className: `badge badge${typeFromStatus(run.state)}`
    }, (0, _startCase2.default)(run.state)));
  }

  return /*#__PURE__*/_react.default.createElement(_react.default.Fragment, null, /*#__PURE__*/_react.default.createElement(ProgressBar, {
    run: run
  }), allowRetry ? /*#__PURE__*/_react.default.createElement("p", null, /*#__PURE__*/_react.default.createElement(_retry.default, {
    org,
    run,
    onRequeued
  })) : null);
};

const ProgressBar = ({
  run
}) => {
  return /*#__PURE__*/_react.default.createElement(_react.default.Fragment, null, /*#__PURE__*/_react.default.createElement("div", {
    className: "progress"
  }, /*#__PURE__*/_react.default.createElement(Progress, {
    isRunning: run.state == "Running",
    isSuccess: true,
    value: run.progress.success,
    total: run.progress.total
  }), /*#__PURE__*/_react.default.createElement(Progress, {
    isRunning: run.state == "Running",
    value: run.progress.failed,
    total: run.progress.total
  })), /*#__PURE__*/_react.default.createElement(_core.ProgressText, {
    progress: run.progress,
    component: "small",
    className: "text-muted"
  }));
};

const Progress = ({
  isRunning,
  isSuccess,
  value,
  total
}) => {
  if (!value) return null;
  const percentage = value / total * 100.0;
  return /*#__PURE__*/_react.default.createElement("div", {
    className: `progress-bar ${isSuccess ? "bg-success" : "bg-danger"} ${isRunning ? "progress-bar-striped progress-bar-animated" : ""}`,
    role: "progressbar",
    style: {
      width: `${percentage}%`
    },
    "aria-valuenow": value,
    "aria-valuemin": value,
    "aria-valuemax": total
  });
};

function typeFromStatus(runStatus) {
  switch (runStatus) {
    case "Enqueued":
      return "-secondary";

    case "Running":
      return "-primary";

    case "Successful":
      return "-success";

    case "Failed":
      return "-danger";

    case "Cancelled":
      return "-warning";

    case "TimedOut":
      return "-danger";

    case "Error":
      return "-danger";

    default:
      return "";
  }
}

function isProgressEmpty(progress) {
  if (!progress) return true;
  if (!progress.success && !progress.failed && !progress.total) return true;
  return false;
}

var _default = RunProgress;
exports.default = _default;